"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var LoggingTimer = /** @class */ (function () {
    function LoggingTimer(options) {
        this.checkpoints = [];
        this.logger = {
            log: console.log,
            warn: console.warn
        };
        var _a = options.name, name = _a === void 0 ? "" : _a, _b = options.logging, logging = _b === void 0 ? true : _b, _c = options.logger, logger = _c === void 0 ? {} : _c;
        this.timerName = name;
        this.loggingEnabled = logging;
        if (typeof logger.log === "function") {
            this.logger.log = logger.log;
        }
        if (typeof logger.warn === "function") {
            this.logger.warn = logger.warn;
        }
    }
    LoggingTimer.getTimestamp = function () {
        return performance.now();
    };
    LoggingTimer.prototype.log = function (message) {
        if (this.loggingEnabled) {
            this.logger.log(message);
        }
    };
    LoggingTimer.prototype.warn = function (message) {
        this.logger.warn(message);
    };
    Object.defineProperty(LoggingTimer.prototype, "latestCheckpoint", {
        get: function () {
            return this.checkpoints.length === 0 ? null : this.checkpoints[this.checkpoints.length - 1];
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LoggingTimer.prototype, "latestTimeElapsed", {
        get: function () {
            var c = this.checkpoints;
            var l = c.length;
            return l < 2 ? null : c[l - 1] - c[l - 2];
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LoggingTimer.prototype, "currentLapIndex", {
        get: function () {
            return this.checkpoints.length > 1 ? this.checkpoints.length - 1 : null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(LoggingTimer.prototype, "logs", {
        get: function () {
            return this.checkpoints;
        },
        enumerable: false,
        configurable: true
    });
    LoggingTimer.prototype.start = function () {
        if (this.checkpoints.length === 0) {
            this.checkpoints.push(LoggingTimer.getTimestamp());
            this.log("TIMER " + this.timerName + " [STARTS]");
        }
        else {
            this.warn("Timer is already started");
        }
    };
    LoggingTimer.prototype.stop = function () {
        if (this.checkpoints.length > 0) {
            this.checkpoints = [];
            this.log("TIMER " + this.timerName + " [STOPPED] [TOOK " + this.latestCheckpoint + "ms]");
        }
        else {
            this.warn("Timer is not yet started");
        }
    };
    LoggingTimer.prototype.lap = function () {
        if (this.checkpoints.length > 0) {
            this.checkpoints.push(LoggingTimer.getTimestamp());
            this.log("TIMER " + this.timerName + " [LAP_" + this.currentLapIndex + "] [TOOK " + this.latestCheckpoint + "ms]");
        }
        else {
            this.warn("Timer is not yet started");
        }
    };
    return LoggingTimer;
}());
exports.default = LoggingTimer;
